==> haskell-tamarin-prover-utils-1.4.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-utils
version: 1.4.1
id: tamarin-prover-utils-1.4.1-D5ufDjkZNOzK01f8ixXgYL
key: tamarin-prover-utils-1.4.1-D5ufDjkZNOzK01f8ixXgYL
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
category: Theorem Provers
abi: bfb149cdcdb867288302a5047fca5151
exposed: True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc
hidden-modules: Control.Monad.Fresh.Class Control.Monad.Trans.Disj
                Control.Monad.Disj.Class
import-dirs: /usr/lib/ghc-8.6.5/site-local/tamarin-prover-utils-1.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tamarin-prover-utils-1.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tamarin-prover-utils-1.4.1
hs-libraries: HStamarin-prover-utils-1.4.1-D5ufDjkZNOzK01f8ixXgYL
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    fclabels-2.0.3.3-4pyYMRW7ZpR7Wol7ycOt3l mtl-2.2.2 pretty-1.1.3.6
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7-KRW1LCxdMiCJrmhxCvzo37
    time-1.8.0.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-utils-1.4.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-utils
version: 1.4.1
id: tamarin-prover-utils-1.4.1-AhIVbtAfS7gEepTUSKZin3
key: tamarin-prover-utils-1.4.1-AhIVbtAfS7gEepTUSKZin3
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
category: Theorem Provers
abi: 0c638fe64be6c3fd5fda3e3ecd6765c2
exposed: True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc
hidden-modules: Control.Monad.Fresh.Class Control.Monad.Trans.Disj
                Control.Monad.Disj.Class
import-dirs: /usr/lib/ghc-8.6.5/site-local/tamarin-prover-utils-1.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tamarin-prover-utils-1.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tamarin-prover-utils-1.4.1
hs-libraries: HStamarin-prover-utils-1.4.1-AhIVbtAfS7gEepTUSKZin3
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv base-4.12.0.0
    base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    fclabels-2.0.3.3-4pyYMRW7ZpR7Wol7ycOt3l mtl-2.2.2 pretty-1.1.3.6
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7-KRW1LCxdMiCJrmhxCvzo37
    time-1.8.0.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
